=======================
PySight Post Processing
=======================

Fluorescence Lifetime Imaging
-----------------------------

.. automodule:: pysight.post_processing.flim
    :members:
    :undoc-members:
    :show-inheritance: